<br>
<img src="docs/source/_static/logo.png" width="300px"/>
<br>
<br>


[![PyPI Version](https://img.shields.io/pypi/v/covseisnet.svg)](https://pypi.org/project/covseisnet/)
[![Conda Version](https://img.shields.io/conda/v/conda-forge/covseisnet)](https://anaconda.org/conda-forge/covseisnet)
[![License](https://img.shields.io/conda/l/conda-forge/covseisnet)](https://www.gnu.org/licenses/lgpl.html)
[![Python Version](https://img.shields.io/pypi/pyversions/covseisnet)](https://pypi.org/project/covseisnet/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Platform](https://img.shields.io/conda/pn/conda-forge/covseisnet)](https://anaconda.org/conda-forge/covseisnet)
[![Pipeline Build](https://gricad-gitlab.univ-grenoble-alpes.fr/covseisnet/covseisnet/badges/develop/pipeline.svg)]()
[![codecov](https://codecov.io/gh/covseisnet/covseisnet/branch/develop/graph/badge.svg?token=N462A7PPRF)](https://codecov.io/gh/covseisnet/covseisnet)


## Overview

This package provides tools for __array signal processing__, with a focus on seismic data. In addition to the classical array processing tools (e.g. beaforming, inter-station cross-correlations) we provide various tools for __source detection and location with blind source separation algorithms__. The project also includes diverse __spectral analysis__ tools. `covseisnet` mostly inherits from [`obpsy`](https://docs.obspy.org) (seismic-data analysis) and [`numpy`](https://numpy.org).

## Documentation

Please see the full documentation available at https://covseisnet.gricad-pages.univ-grenoble-alpes.fr/covseisnet.


